#cloud-config
write_files:
  - content: |
      network:
        version: 2
        renderer: networkd
        ethernets:
          kube:
            optional: false
            match:
              macaddress: 00:50:56:a8:b1:${ address }
            set-name: kube
            addresses:
              - 10.44.1.${ address }/16
            nameservers:
              search: [sch.bme.hu, internal]
              addresses: [152.66.208.1, 8.8.8.8]
            routes:
              - to: default
                via: 10.44.255.254 # RTR Gateway
          admin:
            set-name: admin
            match:
              macaddress: 00:50:56:a8:c1:${ address }
            optional: false
            addresses:
              - 10.0.44.1${ address }/16


    path: /etc/netplan/50-cloud-init.yaml
  - content: |
      Protocol 2
      Port 10022

      HostKey /etc/ssh/ssh_host_rsa_key
      HostKey /etc/ssh/ssh_host_ed25519_key

      KexAlgorithms curve25519-sha256@libssh.org,diffie-hellman-group-exchange-sha256
      Ciphers chacha20-poly1305@openssh.com,aes256-gcm@openssh.com,aes128-gcm@openssh.com,aes256-ctr,aes192-ctr,aes128-ctr
      MACs hmac-sha2-512-etm@openssh.com,hmac-sha2-256-etm@openssh.com,umac-128-etm@openssh.com,hmac-sha2-512,hmac-sha2-256,umac-128@openssh.com

      PermitRootLogin no
      PubkeyAuthentication yes
      PasswordAuthentication no

      MaxAuthTries 6

      ChallengeResponseAuthentication no
      KerberosAuthentication no
      GSSAPIAuthentication no
      UsePAM yes
      AllowAgentForwarding yes
      X11Forwarding yes
      PrintMotd no

      AcceptEnv LANG LC_*

      Subsystem       sftp    /usr/lib/openssh/sftp-server

      AllowUsers ubuntu
    path: /etc/ssh/sshd_config
runcmd:
  - "netplan apply"
  - "systemctl restart ssh"
  # Fix slow sudo, because it tries to dns lookup the hostname first
  - echo "127.0.1.1 $(hostname)" >> /etc/hosts
  # Disable floppy
  - echo "blacklist floppy" | sudo tee /etc/modprobe.d/blacklist-floppy.conf
  - rmmod floppy || true
  - update-initramfs -u
