locals {
  vm_map = {
    k8s-02-mgmt = {
      num_cpus             = 2
      memory               = 1024
      template_uuid        = data.vsphere_virtual_machine.ubuntu2204-cloud-init.id
      datastore_id = data.vsphere_datastore.Linstor.id
      vapp_properties = {
        public-keys = "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIKZ15FeW63PG1M1JnnBUzTrXoVPcn+3YSKKFMfksCXsF ubuntu@k8s-02"
        user-data   = base64encode(file("${path.module}/cloud-init/k8s-02-mgmt.yaml"))
      }
      disk_map = {
        0 = { size = 16 }
      }
      network_interface_map = {
        01 = {
          id          = data.vsphere_network.dvPG-208-Szerver.id
          mac_address = "00:50:56:a8:ef:1b"
        }
        02 = {
          id          = data.vsphere_network.dvPG-044-K8S-BGP-NAT.id
          mac_address = "00:50:56:a8:b1:01"
        }
      }
    }
    master-01-k8s-02 = {
      num_cpus             = 2
      memory               = 5120
      template_uuid        = data.vsphere_virtual_machine.ubuntu2204-cloud-init.id
      datastore_id = data.vsphere_datastore.Linstor.id
      vapp_properties = {
        public-keys = "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIKZ15FeW63PG1M1JnnBUzTrXoVPcn+3YSKKFMfksCXsF ubuntu@k8s-02"
        user-data   = base64encode(data.template_file.kube["master-01-k8s-02"].rendered)
      }
      disk_map = {
        0 = { size = 40 }
      }
      enable_disk_uuid = true
      network_interface_map = {
        01 = {
          id          = data.vsphere_network.dvPG-044-K8S-BGP-NAT.id
          mac_address = "00:50:56:a8:b1:11"
        }
        02 = {
          id          = data.vsphere_network.dvPG-AdminLAN-native.id
          mac_address = "00:50:56:a8:c1:11"
        }
      }
    }
    master-02-k8s-02 = {
      num_cpus             = 2
      memory               = 5120
      template_uuid        = data.vsphere_virtual_machine.ubuntu2204-cloud-init.id
      datastore_id = data.vsphere_datastore.Linstor.id
      vapp_properties = {
        public-keys = "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIKZ15FeW63PG1M1JnnBUzTrXoVPcn+3YSKKFMfksCXsF ubuntu@k8s-02"
        user-data   = base64encode(data.template_file.kube["master-02-k8s-02"].rendered)
      }
      disk_map = {
        0 = { size = 40 }
      }
      enable_disk_uuid = true
      network_interface_map = {
        01 = {
          id          = data.vsphere_network.dvPG-044-K8S-BGP-NAT.id
          mac_address = "00:50:56:a8:b1:12"
        }
        02 = {
          id          = data.vsphere_network.dvPG-AdminLAN-native.id
          mac_address = "00:50:56:a8:c1:12"
        }
      }
    }
    master-03-k8s-02 = {
      num_cpus             = 2
      memory               = 5120
      template_uuid        = data.vsphere_virtual_machine.ubuntu2204-cloud-init.id
      datastore_id = data.vsphere_datastore.Linstor.id
      vapp_properties = {
        public-keys = "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIKZ15FeW63PG1M1JnnBUzTrXoVPcn+3YSKKFMfksCXsF ubuntu@k8s-02"
        user-data   = base64encode(data.template_file.kube["master-03-k8s-02"].rendered)
      }
      disk_map = {
        0 = { size = 40 }
      }
      enable_disk_uuid = true
      network_interface_map = {
        01 = {
          id          = data.vsphere_network.dvPG-044-K8S-BGP-NAT.id
          mac_address = "00:50:56:a8:b1:13"
        }
        02 = {
          id          = data.vsphere_network.dvPG-AdminLAN-native.id
          mac_address = "00:50:56:a8:c1:13"
        }
      }
    }
    worker-01-k8s-02 = {
      num_cpus             = 4
      memory               = 12288
      template_uuid        = data.vsphere_virtual_machine.ubuntu2204-cloud-init.id
      datastore_id = data.vsphere_datastore.Linstor.id
      vapp_properties = {
        public-keys = "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIKZ15FeW63PG1M1JnnBUzTrXoVPcn+3YSKKFMfksCXsF ubuntu@k8s-02"
        user-data   = base64encode(data.template_file.kube["worker-01-k8s-02"].rendered)
      }
      disk_map = {
        0 = { size = 70 }
        1 = { size = 250 }
      }
      enable_disk_uuid = true
      network_interface_map = {
        01 = {
          id          = data.vsphere_network.dvPG-044-K8S-BGP-NAT.id
          mac_address = "00:50:56:a8:b1:21"
        }
        02 = {
          id          = data.vsphere_network.dvPG-AdminLAN-native.id
          mac_address = "00:50:56:a8:c1:21"
        }
      }
    }
    worker-02-k8s-02 = {
      num_cpus             = 4
      memory               = 12288
      template_uuid        = data.vsphere_virtual_machine.ubuntu2204-cloud-init.id
      datastore_id = data.vsphere_datastore.Linstor.id
      vapp_properties = {
        public-keys = "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIKZ15FeW63PG1M1JnnBUzTrXoVPcn+3YSKKFMfksCXsF ubuntu@k8s-02"
        user-data   = base64encode(data.template_file.kube["worker-02-k8s-02"].rendered)
      }
      disk_map = {
        0 = { size = 70 }
        1 = { size = 250 }
      }
      enable_disk_uuid = true
      network_interface_map = {
        01 = {
          id          = data.vsphere_network.dvPG-044-K8S-BGP-NAT.id
          mac_address = "00:50:56:a8:b1:22"
        }
        02 = {
          id          = data.vsphere_network.dvPG-AdminLAN-native.id
          mac_address = "00:50:56:a8:c1:22"
        }
      }
    }
    worker-03-k8s-02 = {
      num_cpus             = 4
      memory               = 12288
      template_uuid        = data.vsphere_virtual_machine.ubuntu2204-cloud-init.id
      datastore_id = data.vsphere_datastore.Linstor.id
      vapp_properties = {
        public-keys = "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIKZ15FeW63PG1M1JnnBUzTrXoVPcn+3YSKKFMfksCXsF ubuntu@k8s-02"
        user-data   = base64encode(data.template_file.kube["worker-03-k8s-02"].rendered)
      }
      disk_map = {
        0 = { size = 70 }
        1 = { size = 250 }
      }
      enable_disk_uuid = true
      network_interface_map = {
        01 = {
          id          = data.vsphere_network.dvPG-044-K8S-BGP-NAT.id
          mac_address = "00:50:56:a8:b1:23"
        }
        02 = {
          id          = data.vsphere_network.dvPG-AdminLAN-native.id
          mac_address = "00:50:56:a8:c1:23"
        }
      }
    }
    worker-04-k8s-02 = {
      num_cpus             = 4
      memory               = 12288
      template_uuid        = data.vsphere_virtual_machine.ubuntu2204-cloud-init.id
      datastore_id = data.vsphere_datastore.Linstor.id
      vapp_properties = {
        public-keys = "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIKZ15FeW63PG1M1JnnBUzTrXoVPcn+3YSKKFMfksCXsF ubuntu@k8s-02"
        user-data   = base64encode(data.template_file.kube["worker-04-k8s-02"].rendered)
      }
      disk_map = {
        0 = { size = 70 }
        1 = { size = 250 }
      }
      enable_disk_uuid = true
      network_interface_map = {
        01 = {
          id          = data.vsphere_network.dvPG-044-K8S-BGP-NAT.id
          mac_address = "00:50:56:a8:b1:24"
        }
        02 = {
          id          = data.vsphere_network.dvPG-AdminLAN-native.id
          mac_address = "00:50:56:a8:c1:24"
        }
      }
    }
  }
}

resource "vsphere_virtual_machine" "vm" {
  for_each = { for k, v in local.vm_map : k => v }

  name                             = each.key
  resource_pool_id                 = data.vsphere_resource_pool.kubernetes.id
  guest_id                         = try(each.value.guest_id, "ubuntu64Guest")
  num_cpus                         = try(each.value.num_cpus, 1)
  memory                           = try(each.value.memory, 1024)
  firmware                         = try(each.value.firmware, "efi")
  folder                           = "KSZK/sysadmin/k8s"
  wait_for_guest_net_timeout       = try(each.value.wait_for_guest_net_timeout, 0)
  wait_for_guest_ip_timeout        = try(each.value.wait_for_guest_ip_timeout, 0)
  sync_time_with_host              = true
  sync_time_with_host_periodically = false

  datastore_cluster_id = try(each.value.datastore_cluster_id, null)
  datastore_id         = try(each.value.datastore_id, null)

  enable_disk_uuid = try(each.value.enable_disk_uuid, false)

  dynamic "clone" {
    for_each = can(each.value.template_uuid) ? [1] : []
    content {
      template_uuid = each.value.template_uuid
    }
  }
  dynamic "vapp" {
    for_each = can(each.value.template_uuid) ? [1] : []
    content {
      properties = {
        public-keys = each.value.vapp_properties.public-keys
        hostname    = try(each.value.vapp_properties.hostname, each.key)
        instance-id = try(each.value.vapp_properties.instance-id, each.key)
        password    = try(each.value.vapp_properties.password, null)
        user-data   = try(each.value.vapp_properties.user-data, null)
      }
    }
  }

  dynamic "network_interface" {
    for_each = each.value.network_interface_map
    content {
      network_id     = network_interface.value.id
      use_static_mac = can(network_interface.value.mac_address)
      mac_address    = try(network_interface.value.mac_address, null)
    }
  }

  dynamic "disk" {
    for_each = each.value.disk_map
    content {
      thin_provisioned = false
      label            = "disk${tostring(disk.key)}"
      size             = disk.value.size
      unit_number      = tonumber(disk.key)
    }
  }

  dynamic "cdrom" {
    for_each = can(each.value.template_uuid) ? [1] : []
    content {
      client_device = true
    }
  }
}
